@@ -2,14 +2,18 @@ mod active_model;
 mod active_model_behavior;
 mod column;
 mod entity;
+mod entity_model;
 mod from_query_result;
 mod model;
 mod primary_key;
+mod relation;
 
 pub use active_model::*;
 pub use active_model_behavior::*;
 pub use column::*;
 pub use entity::*;
+pub use entity_model::*;
 pub use from_query_result::*;
 pub use model::*;
 pub use primary_key::*;
+pub use relation::*;
